package org.acme.quartz;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class TaskResourceIT extends TaskResourceTest {

}
